@@ -11,8 +11,8 @@ EMPHASIS_RE = r'(?<!\w)(_)(.+?)\1(?!\w)'
 
 class JiraWikiExtension(Extension):
     def extendMarkdown(self, md):
+        md.preprocessors.register(code_processor, 'jira-code', 40)
         md.inlinePatterns.register(monospace_processor, 'jira-monospace', 200)
-        md.inlinePatterns.register(code_processor, 'jira-code', 205)
         md.inlinePatterns.register(link_processor, 'jira-link', 210)
         md.inlinePatterns.register(SimpleTagInlineProcessor(STRONG_RE, 'strong'), 'jira-strong', 199)
         md.inlinePatterns.register(SimpleTagInlineProcessor(EMPHASIS_RE, 'em'), 'jira-emphasis', 198)
