@@ -1,12 +1,13 @@
+from xml.etree import ElementTree
+
 from markdown.inlinepatterns import InlineProcessor
-from markdown.util import etree
 
 LINK_PATTERN = r'\[([^|]+)\|https?://(.*?)\]'
 
 
 class LinkProcessor(InlineProcessor):
     def handleMatch(self, m, data):
-        a = etree.Element('a')
+        a = ElementTree.Element('a')
         print(m.groups())
         a.set('href', 'https://' + m.group(2))
         a.text = m.group(1)
